@@ -1698,9 +1698,9 @@ class MetaflowUI(
     jsii_type="cdk8s-metaflow.MetaflowUIOptions",
     jsii_struct_bases=[],
     name_mapping={
-        "env": "env",
         "affinity": "affinity",
         "autoscaling": "autoscaling",
+        "env": "env",
         "env_from": "envFrom",
         "fullname_override": "fullnameOverride",
         "image": "image",
@@ -1726,9 +1726,9 @@ class MetaflowUIOptions:
     def __init__(
         self,
         *,
-        env: typing.Mapping[builtins.str, builtins.str],
         affinity: typing.Optional[_Affinity_9d28a7c5] = None,
         autoscaling: typing.Optional[typing.Union[AutoscalingOptions, typing.Dict[str, typing.Any]]] = None,
+        env: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         env_from: typing.Optional[typing.Sequence[_EnvFromSource_2b00ef0f]] = None,
         fullname_override: typing.Optional[builtins.str] = None,
         image: typing.Optional[typing.Union[ImageOptions, typing.Dict[str, typing.Any]]] = None,
@@ -1750,9 +1750,9 @@ class MetaflowUIOptions:
         ui_image: typing.Optional[typing.Union[ImageOptions, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
-        :param env: 
         :param affinity: 
         :param autoscaling: 
+        :param env: 
         :param env_from: 
         :param fullname_override: 
         :param image: 
@@ -1797,9 +1797,9 @@ class MetaflowUIOptions:
             ui_image = ImageOptions(**ui_image)
         if __debug__:
             type_hints = typing.get_type_hints(MetaflowUIOptions.__init__)
-            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
             check_type(argname="argument affinity", value=affinity, expected_type=type_hints["affinity"])
             check_type(argname="argument autoscaling", value=autoscaling, expected_type=type_hints["autoscaling"])
+            check_type(argname="argument env", value=env, expected_type=type_hints["env"])
             check_type(argname="argument env_from", value=env_from, expected_type=type_hints["env_from"])
             check_type(argname="argument fullname_override", value=fullname_override, expected_type=type_hints["fullname_override"])
             check_type(argname="argument image", value=image, expected_type=type_hints["image"])
@@ -1819,13 +1819,13 @@ class MetaflowUIOptions:
             check_type(argname="argument service_static", value=service_static, expected_type=type_hints["service_static"])
             check_type(argname="argument tolerations", value=tolerations, expected_type=type_hints["tolerations"])
             check_type(argname="argument ui_image", value=ui_image, expected_type=type_hints["ui_image"])
-        self._values: typing.Dict[str, typing.Any] = {
-            "env": env,
-        }
+        self._values: typing.Dict[str, typing.Any] = {}
         if affinity is not None:
             self._values["affinity"] = affinity
         if autoscaling is not None:
             self._values["autoscaling"] = autoscaling
+        if env is not None:
+            self._values["env"] = env
         if env_from is not None:
             self._values["env_from"] = env_from
         if fullname_override is not None:
@@ -1865,15 +1865,6 @@ class MetaflowUIOptions:
         if ui_image is not None:
             self._values["ui_image"] = ui_image
 
-    @builtins.property
-    def env(self) -> typing.Mapping[builtins.str, builtins.str]:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("env")
-        assert result is not None, "Required property 'env' is missing"
-        return typing.cast(typing.Mapping[builtins.str, builtins.str], result)
-
     @builtins.property
     def affinity(self) -> typing.Optional[_Affinity_9d28a7c5]:
         '''
@@ -1890,6 +1881,14 @@ class MetaflowUIOptions:
         result = self._values.get("autoscaling")
         return typing.cast(typing.Optional[AutoscalingOptions], result)
 
+    @builtins.property
+    def env(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("env")
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
+
     @builtins.property
     def env_from(self) -> typing.Optional[typing.List[_EnvFromSource_2b00ef0f]]:
         '''
